# 云枢 DevOps 支持

注意: 实验性功能

## 准备

### 系统与工具

1. 操作系统: 推荐CentOS 7.9+ 或者 Ubuntu 20.04
2. 构建和推送镜像，需要安装`docker`
3. 部署到K8S集群，需要安装`kubectl`并配置正确
4. 推荐使用K3S测试验证



## 使用

### 获取此工程

```
$ git clone https://gitlab.h3yun.com/h3bpm/foundation/devops.git 
```

注意: 此工程暂未对外开放


### 使用帮助

```
$ cd devops 
$ bash cicd.sh --help
```

### 环境变量配置

- 默认环境变量配置

默认会加载文件: `default_env.sh`

打印当前生效的配置

```
$ bash cicd.sh print-env-vars
```

- 自定义环境变量配置

方式1: 可以修改`default_env.sh`

方式2: 可以复制一个文件来进行配置(推荐方式)

```
$ cp ./default_env.sh ~/workspace/ehr/env.sh
$ vim ~/workspace/ehr/env.sh
...
export CP_K8S_NAMESPACE=cloudpivot_ehr
...
$ ENV_FILE=~/workspace/ehr/env.sh bash cicd.sh push-image ../web-api
```

### 构建镜像

- 构建单个工程:

```
$ cd devops
$ bash cicd.sh build-image ../web-api
```

`../web-api` 为web-api工程所在的目录, 可使用绝对路径,如

`$ bash cicd.sh build-image /data/web-api`

*构建多个工程:

```
$ cd devops
$ bash cicd.sh build-image ../web-api ../frontend
```

### 推送镜像

*推送单个工程:

```
$ bash cicd.sh push-image ../web-api
```

*推送多个工程:

```
$ bash cicd.sh push-image ../web-api ../frontend
```

### 一键部署到K8S

```
$ bash cicd.sh k8s-deploy
```

## 与CI 流水线配合

* 准备工作空间

示例脚本如下:

```
$ cd $WORKSPACE
$ git clone https://gitlab.h3yun.com/h3bpm/foundation/devops.git

$ export TAG="6.8.0"

$ git clone https://somehost/h3bpm/backend/web-api.git 
$ ( cd web-api && $ git fetch --tags && git checkout $TAG -b $TAG )

$ git clone https://somehost/h3bpm/frontend/frontend.git
$ ( cd frontend && $ git fetch --tags && git checkout $TAG -b $TAG ) 
```

* CI工作目录结构

```
$ tree $WORKSPACE -L 1 
.
├── cloudpivot.license           # 部署时用到的license文件
├── devops                       # 此devops工程，从云枢分发包获取（有问题联系技术支持）
├── frontend                     # 前端源码工程
└── web-api                      # 后端源码工程
```

CICD脚本示例

```
$ cd $WORKSPACE
$ cp devops/default_env.sh env.sh

$ vim env.sh

$ cd devops
$ ENV_FILE=../env.sh bash cicd.sh build-image ../web-api ../frontend

$ ENV_FILE=../env.sh bash cicd.sh push-image ../web-api ../frontend

$ ENV_FILE=../env.sh bash cicd.sh k8s-deploy

```


## 说明

### 镜像版本规则

前端项目: package.json -> version

Maven项目: pom.xml -> project.version

### 镜像仓库名规则

前端项目: package.json -> name

Maven项目: pom.xml -> project.name
